## Info on typeshed's stubs for `D3DShot`

### Stub distribution name

`types-D3DShot`

### Number of lines

585 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `D3DShot` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `D3DShot`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 127
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 255
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 100
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 43
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `DateTimeRange`

### Stub distribution name

`types-DateTimeRange`

### Number of lines

64 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `DateTimeRange` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `DateTimeRange`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 28
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 10
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Deprecated`

### Stub distribution name

`types-Deprecated`

### Number of lines

56 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Deprecated` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Deprecated`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ExifRead`

### Stub distribution name

`types-ExifRead`

### Number of lines

218 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `ExifRead` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ExifRead`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 72
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 52
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 82
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Cors`

### Stub distribution name

`types-Flask-Cors`

### Number of lines

124 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Flask-Cors` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Flask-Cors`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 62
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 30
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-Migrate`

### Stub distribution name

`types-Flask-Migrate`

### Number of lines

100 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Flask-Migrate` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Flask-Migrate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 74
    - Unannotated parameters: 4
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 2
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 7
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Flask-SQLAlchemy`

### Stub distribution name

`types-Flask-SQLAlchemy`

### Number of lines

106 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `Flask-SQLAlchemy` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Flask-SQLAlchemy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 54
    - Unannotated parameters: 21
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 23
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 19
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 16
    - Explicit `Any` variables: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `JACK-Client`

### Stub distribution name

`types-JACK-Client`

### Number of lines

309 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 0 allowlist entries for `JACK-Client` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `JACK-Client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 107
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 151
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 46
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Markdown`

### Stub distribution name

`types-Markdown`

### Number of lines

641 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 12 allowlist entries for `Markdown` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Markdown`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 115
    - Unannotated parameters: 143
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 64
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 215
    - Explicit `Any` variables: 83
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 99
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Pillow`

### Stub distribution name

`types-Pillow`

### Number of lines

2,537 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `Pillow` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Pillow`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 653
    - Unannotated parameters: 613
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 60
- Returns:
    - Annotated returns: 466
    - Unannotated returns: 340
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 847
    - Explicit `Any` variables: 323
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 8
- Class definitions:
    - Total class definitions: 204
    - Class definitions with `Any`: 4
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyAutoGUI`

### Stub distribution name

`types-PyAutoGUI`

### Number of lines

229 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `PyAutoGUI` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyAutoGUI`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 145
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 38
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 22
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyMySQL`

### Stub distribution name

`types-PyMySQL`

### Number of lines

1,041 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 allowlist entries for `PyMySQL` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyMySQL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 139
    - Unannotated parameters: 53
    - Explicit `Any` parameters: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 28
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 40
    - Explicit `Any` returns: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 733
    - Explicit `Any` variables: 62
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyScreeze`

### Stub distribution name

`types-PyScreeze`

### Number of lines

183 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `PyScreeze` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `PyScreeze`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 93
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 18
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `PyYAML`

### Stub distribution name

`types-PyYAML`

### Number of lines

1,177 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `PyYAML` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `PyYAML`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 395
    - Unannotated parameters: 315
    - Explicit `Any` parameters: 40
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 12
- Returns:
    - Annotated returns: 158
    - Unannotated returns: 230
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 189
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 91
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `Pygments`

### Stub distribution name

`types-Pygments`

### Number of lines

687 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `Pygments` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `Pygments`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 157
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 17
- Returns:
    - Annotated returns: 96
    - Unannotated returns: 79
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 313
    - Explicit `Any` variables: 193
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 62
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `SQLAlchemy`

### Extra description

The `sqlalchemy-stubs` package is an alternative to this package and also includes a mypy plugin for more precise types.

### Stub distribution name

`types-SQLAlchemy`

### Number of lines

14,666 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1,153 allowlist entries for `SQLAlchemy` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `SQLAlchemy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,117
    - Unannotated parameters: 7,007
    - Explicit `Any` parameters: 67
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1,141
- Returns:
    - Annotated returns: 2,115
    - Unannotated returns: 3,317
    - Explicit `Any` returns: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,089
    - Explicit `Any` variables: 1,859
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 197
- Class definitions:
    - Total class definitions: 1,329
    - Class definitions with `Any`: 62
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `Send2Trash`

### Stub distribution name

`types-Send2Trash`

### Number of lines

21 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `Send2Trash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `Send2Trash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aiofiles`

### Stub distribution name

`types-aiofiles`

### Number of lines

590 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 57 allowlist entries for `aiofiles` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `aiofiles`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 342
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 24
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 26
- Returns:
    - Annotated returns: 136
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `annoy`

### Stub distribution name

`types-annoy`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `annoy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `annoy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 40
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `appdirs`

### Stub distribution name

`types-appdirs`

### Number of lines

54 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `appdirs` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `appdirs`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 33
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 15
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `aws-xray-sdk`

### Stub distribution name

`types-aws-xray-sdk`

### Number of lines

711 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `aws-xray-sdk` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `aws-xray-sdk`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 127
    - Unannotated parameters: 166
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 180
    - Unannotated returns: 94
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 141
    - Explicit `Any` variables: 46
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 45
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `babel`

### Stub distribution name

`types-babel`

### Number of lines

1,134 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `babel` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `babel`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 497
    - Unannotated parameters: 136
    - Explicit `Any` parameters: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 15
- Returns:
    - Annotated returns: 300
    - Unannotated returns: 79
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 257
    - Explicit `Any` variables: 100
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 45
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `backports.ssl_match_hostname`

### Stub distribution name

`types-backports.ssl_match_hostname`

### Number of lines

6 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `backports.ssl_match_hostname` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `backports.ssl_match_hostname`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `beautifulsoup4`

### Stub distribution name

`types-beautifulsoup4`

### Number of lines

795 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `beautifulsoup4` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `beautifulsoup4`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 239
    - Unannotated parameters: 137
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 31
- Returns:
    - Annotated returns: 192
    - Unannotated returns: 49
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 177
    - Explicit `Any` variables: 69
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 47
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `bleach`

### Stub distribution name

`types-bleach`

### Number of lines

187 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `bleach` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `bleach`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 64
    - Unannotated parameters: 21
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 26
    - Unannotated returns: 16
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 7
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `boto`

### Stub distribution name

`types-boto`

### Number of lines

1,891 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 allowlist entries for `boto` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `boto`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 837
    - Unannotated parameters: 685
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 345
- Returns:
    - Annotated returns: 168
    - Unannotated returns: 442
    - Explicit `Any` returns: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 363
    - Explicit `Any` variables: 267
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 136
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `braintree`

### Stub distribution name

`types-braintree`

### Number of lines

2,859 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `braintree` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `braintree`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 80
    - Unannotated parameters: 394
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 75
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 304
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1,301
    - Explicit `Any` variables: 432
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 234
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cachetools`

### Stub distribution name

`types-cachetools`

### Number of lines

119 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 allowlist entries for `cachetools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `cachetools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 87
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 48
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `caldav`

### Stub distribution name

`types-caldav`

### Number of lines

499 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 allowlist entries for `caldav` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `caldav`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 205
    - Unannotated parameters: 30
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 17
- Returns:
    - Annotated returns: 116
    - Unannotated returns: 8
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 92
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 86
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `cffi`

### Stub distribution name

`types-cffi`

### Number of lines

820 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 5 allowlist entries for `cffi` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `cffi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 295
    - Unannotated parameters: 251
    - Explicit `Any` parameters: 32
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 191
    - Unannotated returns: 132
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 252
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 115
- Class definitions:
    - Total class definitions: 52
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `chardet`

### Stub distribution name

`types-chardet`

### Number of lines

122 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 25 allowlist entries for `chardet` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `chardet`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 7
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 86
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 10
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `chevron`

### Stub distribution name

`types-chevron`

### Number of lines

37 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `chevron` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `chevron`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 29
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `click-spinner`

### Stub distribution name

`types-click-spinner`

### Number of lines

30 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `click-spinner` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `click-spinner`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `colorama`

### Stub distribution name

`types-colorama`

### Number of lines

198 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 45 allowlist entries for `colorama` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `colorama`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 89
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 85
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `commonmark`

### Stub distribution name

`types-commonmark`

### Number of lines

370 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `commonmark` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `commonmark`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 158
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 55
- Returns:
    - Annotated returns: 84
    - Unannotated returns: 76
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 133
    - Explicit `Any` variables: 86
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 18
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `console-menu`

### Stub distribution name

`types-console-menu`

### Number of lines

687 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `console-menu` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `console-menu`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 278
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 39
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `contextvars`

### Stub distribution name

`types-contextvars`

### Number of lines

41 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `contextvars` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `contextvars`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 12
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `croniter`

### Stub distribution name

`types-croniter`

### Number of lines

136 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `croniter` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `croniter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 23
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dateparser`

### Stub distribution name

`types-dateparser`

### Number of lines

468 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `dateparser` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `dateparser`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 126
    - Unannotated parameters: 127
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 67
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 135
    - Explicit `Any` variables: 76
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 34
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `decorator`

### Stub distribution name

`types-decorator`

### Number of lines

66 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 9 allowlist entries for `decorator` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `decorator`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dj-database-url`

### Stub distribution name

`types-dj-database-url`

### Number of lines

37 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dj-database-url` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dj-database-url`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 15
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `dockerfile-parse`

### Stub distribution name

`types-dockerfile-parse`

### Number of lines

111 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `dockerfile-parse` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `dockerfile-parse`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 24
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 39
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docopt`

### Stub distribution name

`types-docopt`

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `docopt` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `docopt`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `docutils`

### Stub distribution name

`types-docutils`

### Number of lines

502 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 19 allowlist entries for `docutils` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `docutils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 213
    - Unannotated parameters: 60
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 30
- Returns:
    - Annotated returns: 148
    - Unannotated returns: 10
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 45
- Variables:
    - Annotated variables: 80
    - Explicit `Any` variables: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 46
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `editdistance`

### Stub distribution name

`types-editdistance`

### Number of lines

3 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `editdistance` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `editdistance`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `emoji`

### Stub distribution name

`types-emoji`

### Number of lines

66 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `emoji` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `emoji`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 21
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 10
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `entrypoints`

### Stub distribution name

`types-entrypoints`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `entrypoints` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `entrypoints`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 23
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `first`

### Stub distribution name

`types-first`

### Number of lines

14 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `first` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `first`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-2020`

### Stub distribution name

`types-flake8-2020`

### Number of lines

22 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-2020` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-2020`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-bugbear`

### Stub distribution name

`types-flake8-bugbear`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `flake8-bugbear` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-bugbear`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 8
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 8
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-builtins`

### Stub distribution name

`types-flake8-builtins`

### Number of lines

10 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-builtins` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-builtins`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-docstrings`

### Stub distribution name

`types-flake8-docstrings`

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 6
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-plugin-utils`

### Stub distribution name

`types-flake8-plugin-utils`

### Number of lines

61 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `flake8-plugin-utils` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-plugin-utils`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-rst-docstrings`

### Stub distribution name

`types-flake8-rst-docstrings`

### Number of lines

31 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-rst-docstrings` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-rst-docstrings`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-simplify`

### Stub distribution name

`types-flake8-simplify`

### Number of lines

8 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-simplify` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-simplify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `flake8-typing-imports`

### Stub distribution name

`types-flake8-typing-imports`

### Number of lines

15 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `flake8-typing-imports` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `flake8-typing-imports`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 2
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `fpdf2`

### Stub distribution name

`types-fpdf2`

### Number of lines

2,185 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 allowlist entries for `fpdf2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `fpdf2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 642
    - Unannotated parameters: 528
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 67
- Returns:
    - Annotated returns: 417
    - Unannotated returns: 194
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 676
    - Explicit `Any` variables: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 160
- Class definitions:
    - Total class definitions: 156
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `gdb`

### Extra description

Type hints for GDB's [Python API](https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html). Note that this API is available only when running Python scripts under GDB: is is not possible to install the `gdb` package separately, for instance using `pip`.

### Stub distribution name

`types-gdb`

### Number of lines

733 (excluding blank lines)

### Package status: *not on pypi*

The runtime package that these stubs are for doesn't exist on PyPI, so whether or not these stubs are up to date or not is unknown.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *skipped*

Stubtest is skipped in typeshed's CI for this package.

Typeshed currently has 0 allowlist entries for `gdb` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `gdb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 233
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 257
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 290
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 87
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `google-cloud-ndb`

### Stub distribution name

`types-google-cloud-ndb`

### Number of lines

1,415 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 allowlist entries for `google-cloud-ndb` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `google-cloud-ndb`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 479
    - Unannotated parameters: 368
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 123
- Returns:
    - Annotated returns: 234
    - Unannotated returns: 203
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 190
    - Explicit `Any` variables: 132
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `hdbcli`

### Stub distribution name

`types-hdbcli`

### Number of lines

129 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 allowlist entries for `hdbcli` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `hdbcli`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 77
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 6
- Returns:
    - Annotated returns: 62
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 21
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `html5lib`

### Stub distribution name

`types-html5lib`

### Number of lines

673 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `html5lib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `html5lib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 67
    - Unannotated parameters: 207
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 27
- Returns:
    - Annotated returns: 100
    - Unannotated returns: 208
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 220
    - Explicit `Any` variables: 180
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 40
    - Class definitions with `Any`: 4
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `httplib2`

### Stub distribution name

`types-httplib2`

### Number of lines

253 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `httplib2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `httplib2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 122
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 37
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 25
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 86
    - Explicit `Any` variables: 57
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 33
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `humanfriendly`

### Stub distribution name

`types-humanfriendly`

### Number of lines

340 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 allowlist entries for `humanfriendly` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `humanfriendly`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 79
    - Unannotated parameters: 181
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 22
- Returns:
    - Annotated returns: 82
    - Unannotated returns: 95
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 75
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 25
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ibm-db`

### Stub distribution name

`types-ibm-db`

### Number of lines

252 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ibm-db` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ibm-db`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 162
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 65
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 110
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `influxdb-client`

### Stub distribution name

`types-influxdb-client`

### Number of lines

13,317 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `influxdb-client` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `influxdb-client`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,269
    - Unannotated parameters: 3,800
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1,979
- Returns:
    - Annotated returns: 1,857
    - Unannotated returns: 3,446
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 1,178
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1,076
- Class definitions:
    - Total class definitions: 423
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `invoke`

### Stub distribution name

`types-invoke`

### Number of lines

741 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `invoke` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `invoke`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 243
    - Unannotated parameters: 171
    - Explicit `Any` parameters: 28
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 174
    - Unannotated returns: 73
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 128
    - Explicit `Any` variables: 70
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 43
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jmespath`

### Stub distribution name

`types-jmespath`

### Number of lines

172 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jmespath` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jmespath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 81
    - Unannotated parameters: 52
    - Explicit `Any` parameters: 27
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 50
    - Unannotated returns: 24
    - Explicit `Any` returns: 27
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 22
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `jsonschema`

### Stub distribution name

`types-jsonschema`

### Number of lines

389 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `jsonschema` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `jsonschema`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 108
    - Unannotated parameters: 295
    - Explicit `Any` parameters: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 12
- Returns:
    - Annotated returns: 145
    - Unannotated returns: 31
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 54
    - Explicit `Any` variables: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 25
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `keyboard`

### Stub distribution name

`types-keyboard`

### Number of lines

240 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `keyboard` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `keyboard`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 130
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 76
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 38
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ldap3`

### Stub distribution name

`types-ldap3`

### Number of lines

2,648 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ldap3` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `ldap3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 558
    - Unannotated parameters: 654
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 282
- Returns:
    - Annotated returns: 219
    - Unannotated returns: 421
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 931
    - Explicit `Any` variables: 322
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 57
- Class definitions:
    - Total class definitions: 316
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mock`

### Stub distribution name

`types-mock`

### Number of lines

359 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `mock` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `mock`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 204
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 76
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 47
- Returns:
    - Annotated returns: 85
    - Unannotated returns: 0
    - Explicit `Any` returns: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 34
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 23
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mypy-extensions`

### Stub distribution name

`types-mypy-extensions`

### Number of lines

71 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `mypy-extensions` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `mypy-extensions`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `mysqlclient`

### Stub distribution name

`types-mysqlclient`

### Number of lines

1,215 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `mysqlclient` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `mysqlclient`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 128
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 83
    - Unannotated returns: 30
    - Explicit `Any` returns: 51
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 972
    - Explicit `Any` variables: 31
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 35
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `netaddr`

### Stub distribution name

`types-netaddr`

### Number of lines

659 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `netaddr` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `netaddr`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 292
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 310
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 103
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 43
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `oauthlib`

### Stub distribution name

`types-oauthlib`

### Number of lines

1,385 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `oauthlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `oauthlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 274
    - Unannotated parameters: 541
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 185
- Returns:
    - Annotated returns: 139
    - Unannotated returns: 211
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 318
    - Explicit `Any` variables: 207
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 106
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `openpyxl`

### Stub distribution name

`types-openpyxl`

### Number of lines

9,276 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `openpyxl` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `openpyxl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2,690
    - Unannotated parameters: 607
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2,186
- Returns:
    - Annotated returns: 819
    - Unannotated returns: 356
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 18
- Variables:
    - Annotated variables: 4,197
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3,559
- Class definitions:
    - Total class definitions: 566
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 5

---

## Info on typeshed's stubs for `opentracing`

### Stub distribution name

`types-opentracing`

### Number of lines

329 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `opentracing` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `opentracing`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 105
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 1
- Returns:
    - Annotated returns: 113
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 56
    - Explicit `Any` variables: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `paho-mqtt`

### Stub distribution name

`types-paho-mqtt`

### Number of lines

503 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `paho-mqtt` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `paho-mqtt`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 217
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 147
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 145
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 19
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `paramiko`

### Stub distribution name

`types-paramiko`

### Number of lines

1,724 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 14 allowlist entries for `paramiko` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `paramiko`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 738
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 20
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 623
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 529
    - Explicit `Any` variables: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 113
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `parsimonious`

### Stub distribution name

`types-parsimonious`

### Number of lines

181 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `parsimonious` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `parsimonious`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 114
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 23
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 60
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2
- Class definitions:
    - Total class definitions: 27
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passlib`

### Stub distribution name

`types-passlib`

### Number of lines

1,778 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 31 allowlist entries for `passlib` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `passlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 382
    - Unannotated parameters: 466
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 156
- Returns:
    - Annotated returns: 155
    - Unannotated returns: 329
    - Explicit `Any` returns: 10
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 576
    - Explicit `Any` variables: 101
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 143
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `passpy`

### Stub distribution name

`types-passpy`

### Number of lines

47 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 allowlist entries for `passpy` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `passpy`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 20
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `peewee`

### Stub distribution name

`types-peewee`

### Number of lines

1,609 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 25 allowlist entries for `peewee` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `peewee`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 370
    - Unannotated parameters: 704
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 244
- Returns:
    - Annotated returns: 298
    - Unannotated returns: 448
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 5
- Variables:
    - Annotated variables: 437
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 368
- Class definitions:
    - Total class definitions: 166
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pep8-naming`

### Stub distribution name

`types-pep8-naming`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `pep8-naming` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pep8-naming`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 10
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 8
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 11
    - Explicit `Any` variables: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pika`

### Extra description

The `types-pika` package contains alternate, more complete type stubs, that are maintained outside of typeshed.

### Stub distribution name

`types-pika-ts`

### Number of lines

2,187 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 20 allowlist entries for `pika` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pika`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 604
    - Unannotated parameters: 397
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 141
- Returns:
    - Annotated returns: 390
    - Unannotated returns: 370
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 470
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 261
- Class definitions:
    - Total class definitions: 222
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `playsound`

### Stub distribution name

`types-playsound`

### Number of lines

5 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `playsound` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `playsound`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 1
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `polib`

### Stub distribution name

`types-polib`

### Number of lines

144 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `polib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `polib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 61
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 18
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 75
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 45
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 8
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `prettytable`

### Stub distribution name

`types-prettytable`

### Number of lines

294 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `prettytable` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `prettytable`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 18
    - Unannotated parameters: 77
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 56
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 34
    - Explicit `Any` variables: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `protobuf`

### Extra description

Generated with aid from mypy-protobuf v3.4.0

### Stub distribution name

`types-protobuf`

### Number of lines

4,281 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 14 allowlist entries for `protobuf` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `protobuf`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 726
    - Unannotated parameters: 248
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 14
- Returns:
    - Annotated returns: 494
    - Unannotated returns: 79
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 738
    - Explicit `Any` variables: 126
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 147
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psutil`

### Stub distribution name

`types-psutil`

### Number of lines

1,546 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 20 allowlist entries for `psutil` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `psutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 117
    - Unannotated parameters: 310
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 28
- Returns:
    - Annotated returns: 185
    - Unannotated returns: 358
    - Explicit `Any` returns: 47
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 610
    - Explicit `Any` variables: 203
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 99
- Class definitions:
    - Total class definitions: 90
    - Class definitions with `Any`: 3
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `psycopg2`

### Stub distribution name

`types-psycopg2`

### Number of lines

1,563 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 allowlist entries for `psycopg2` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `psycopg2`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 171
    - Unannotated parameters: 328
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 52
- Returns:
    - Annotated returns: 189
    - Unannotated returns: 169
    - Explicit `Any` returns: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 532
    - Explicit `Any` variables: 168
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 335
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyOpenSSL`

### Stub distribution name

`types-pyOpenSSL`

### Number of lines

374 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `pyOpenSSL` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyOpenSSL`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 163
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 4
- Returns:
    - Annotated returns: 198
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 2
- Variables:
    - Annotated variables: 120
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 25
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyRFC3339`

### Stub distribution name

`types-pyRFC3339`

### Number of lines

17 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyRFC3339` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyRFC3339`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyasn1`

### Stub distribution name

`types-pyasn1`

### Number of lines

1,316 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 5 allowlist entries for `pyasn1` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pyasn1`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 196
    - Unannotated parameters: 501
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 38
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 411
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 6
- Variables:
    - Annotated variables: 207
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 164
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyaudio`

### Stub distribution name

`types-pyaudio`

### Number of lines

165 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin` and `linux`.

Typeshed currently has 0 allowlist entries for `pyaudio` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyaudio`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 37
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycocotools`

### Stub distribution name

`types-pycocotools`

### Number of lines

172 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pycocotools` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pycocotools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 51
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 64
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 11
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pycurl`

### Stub distribution name

`types-pycurl`

### Number of lines

674 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pycurl` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pycurl`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 22
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 7
- Returns:
    - Annotated returns: 32
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 10
- Variables:
    - Annotated variables: 629
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyfarmhash`

### Stub distribution name

`types-pyfarmhash`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pyfarmhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyfarmhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 9
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyflakes`

### Stub distribution name

`types-pyflakes`

### Number of lines

428 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 24 allowlist entries for `pyflakes` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pyflakes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 267
    - Unannotated parameters: 69
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 210
    - Unannotated returns: 2
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 33
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 74
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyinstaller`

### Stub distribution name

`types-pyinstaller`

### Number of lines

429 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 33 allowlist entries for `pyinstaller` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyinstaller`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 188
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 117
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 98
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 18
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pynput`

### Stub distribution name

`types-pynput`

### Number of lines

324 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 14 allowlist entries for `pynput` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pynput`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 81
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 71
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 24
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pyserial`

### Stub distribution name

`types-pyserial`

### Number of lines

1,033 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 84 allowlist entries for `pyserial` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyserial`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 205
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 251
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 466
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 66
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pysftp`

### Stub distribution name

`types-pysftp`

### Number of lines

161 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `pysftp` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pysftp`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 109
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 70
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytest-lazy-fixture`

### Stub distribution name

`types-pytest-lazy-fixture`

### Number of lines

12 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 7 allowlist entries for `pytest-lazy-fixture` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pytest-lazy-fixture`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 5
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 5
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-crontab`

### Stub distribution name

`types-python-crontab`

### Number of lines

292 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `python-crontab` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-crontab`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 137
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 17
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 133
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 4
- Variables:
    - Annotated variables: 66
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 17
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 1

---

## Info on typeshed's stubs for `python-datemath`

### Stub distribution name

`types-python-datemath`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `python-datemath` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-datemath`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-dateutil`

### Stub distribution name

`types-python-dateutil`

### Number of lines

440 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 allowlist entries for `python-dateutil` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-dateutil`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 171
    - Unannotated parameters: 66
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 5
- Returns:
    - Annotated returns: 106
    - Unannotated returns: 48
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 90
    - Explicit `Any` variables: 13
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 29
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-gflags`

### Stub distribution name

`types-python-gflags`

### Number of lines

251 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `python-gflags` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-gflags`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 186
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 98
    - Unannotated returns: 0
    - Explicit `Any` returns: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 19
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 27
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-jose`

### Stub distribution name

`types-python-jose`

### Number of lines

356 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `python-jose` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `python-jose`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 86
    - Unannotated parameters: 39
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 4
- Returns:
    - Annotated returns: 64
    - Unannotated returns: 26
    - Explicit `Any` returns: 12
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 117
    - Explicit `Any` variables: 30
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 26
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-nmap`

### Stub distribution name

`types-python-nmap`

### Number of lines

116 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `python-nmap` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-nmap`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 44
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 44
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 31
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-slugify`

### Stub distribution name

`types-python-slugify`

### Number of lines

45 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `python-slugify` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-slugify`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 12
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `python-xlib`

### Stub distribution name

`types-python-xlib`

### Number of lines

5,385 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 allowlist entries for `python-xlib` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `python-xlib`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 1,332
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 15
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 581
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3,525
    - Explicit `Any` variables: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 425
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pytz`

### Stub distribution name

`types-pytz`

### Number of lines

128 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 4 allowlist entries for `pytz` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pytz`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 69
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 2
- Returns:
    - Annotated returns: 51
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 27
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 16
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 3

---

## Info on typeshed's stubs for `pyvmomi`

### Stub distribution name

`types-pyvmomi`

### Number of lines

177 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 8 allowlist entries for `pyvmomi` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `pyvmomi`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 50
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 35
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 16
- Variables:
    - Annotated variables: 57
    - Explicit `Any` variables: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 44
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `pywin32`

### Stub distribution name

`types-pywin32`

### Number of lines

34,533 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `win32` only.

Typeshed currently has 49 allowlist entries for `pywin32` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `pywin32`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,635
    - Unannotated parameters: 3,729
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 426
- Returns:
    - Annotated returns: 3,825
    - Unannotated returns: 2,043
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 292
- Variables:
    - Annotated variables: 25,025
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 2,832
- Class definitions:
    - Total class definitions: 724
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `redis`

### Stub distribution name

`types-redis`

### Number of lines

5,610 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 68 allowlist entries for `redis` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `redis`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 3,578
    - Unannotated parameters: 1,293
    - Explicit `Any` parameters: 68
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 349
- Returns:
    - Annotated returns: 1,325
    - Unannotated returns: 645
    - Explicit `Any` returns: 322
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 8
- Variables:
    - Annotated variables: 624
    - Explicit `Any` variables: 214
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 34
- Class definitions:
    - Total class definitions: 213
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 2

---

## Info on typeshed's stubs for `regex`

### Stub distribution name

`types-regex`

### Number of lines

748 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 13 allowlist entries for `regex` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `regex`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 429
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 25
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 114
    - Unannotated returns: 0
    - Explicit `Any` returns: 16
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 72
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `requests`

### Stub distribution name

`types-requests`

### Number of lines

970 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 12 allowlist entries for `requests` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `requests`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 353
    - Unannotated parameters: 153
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 19
- Returns:
    - Annotated returns: 111
    - Unannotated returns: 86
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 114
    - Explicit `Any` variables: 39
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 51
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `retry`

### Stub distribution name

`types-retry`

### Number of lines

28 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 allowlist entries for `retry` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `retry`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 17
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `setuptools`

### Stub distribution name

`types-setuptools`

### Number of lines

2,443 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 30 allowlist entries for `setuptools` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `setuptools`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 821
    - Unannotated parameters: 390
    - Explicit `Any` parameters: 29
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 47
- Returns:
    - Annotated returns: 658
    - Unannotated returns: 260
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 1
- Variables:
    - Annotated variables: 624
    - Explicit `Any` variables: 381
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 24
- Class definitions:
    - Total class definitions: 154
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `simplejson`

### Stub distribution name

`types-simplejson`

### Number of lines

51 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 14 allowlist entries for `simplejson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `simplejson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 36
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 14
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 16
    - Unannotated returns: 0
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 17
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 6
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `singledispatch`

### Stub distribution name

`types-singledispatch`

### Number of lines

27 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `singledispatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `singledispatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 16
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 12
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `six`

### Stub distribution name

`types-six`

### Number of lines

335 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 25 allowlist entries for `six` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `six`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 9
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 40
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 13
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `slumber`

### Stub distribution name

`types-slumber`

### Number of lines

74 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `slumber` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `slumber`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 43
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 11
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 9
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 15
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for the stdlib

### Number of lines

51,582 (excluding blank lines)

### Package status: *stdlib*

These are typeshed's stubs for the standard library. Typeshed's stdlib stubs are generally fairly up to date, and are tested against all currently supported Python versions in typeshed's CI.

### Upload status: *not currently uploaded*

These stubs are not currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `darwin`, `linux` and `win32`.

Typeshed currently has 1,553 allowlist entries for the stdlib when running stubtest in CI.

### Pyright settings in CI: *strict on some files*

Some files in this stubs package are tested with the stricter pyright settings in typeshed's CI; some are excluded from the stricter settings.

### Statistics on the annotations in typeshed's stubs for the stdlib

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 24,716
    - Unannotated parameters: 720
    - Explicit `Any` parameters: 2,042
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 88
- Returns:
    - Annotated returns: 13,396
    - Unannotated returns: 417
    - Explicit `Any` returns: 825
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 18
- Variables:
    - Annotated variables: 8,120
    - Explicit `Any` variables: 556
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 125
- Class definitions:
    - Total class definitions: 2,242
    - Class definitions with `Any`: 22
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `stdlib-list`

### Stub distribution name

`types-stdlib-list`

### Number of lines

16 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `stdlib-list` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `stdlib-list`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `stripe`

### Stub distribution name

`types-stripe`

### Number of lines

1,483 (excluding blank lines)

### Package status: *out of date*

These stubs may be out of date. In typeshed's CI, [stubtest][] tests these stubs against an older version of the runtime package than the latest that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 6 allowlist entries for `stripe` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `stripe`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 264
    - Unannotated parameters: 388
    - Explicit `Any` parameters: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 156
- Returns:
    - Annotated returns: 108
    - Unannotated returns: 168
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 42
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 134
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tabulate`

### Stub distribution name

`types-tabulate`

### Number of lines

60 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `tabulate` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tabulate`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 15
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 26
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 4
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tensorflow`

### Stub distribution name

`types-tensorflow`

### Number of lines

592 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 14 allowlist entries for `tensorflow` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tensorflow`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 393
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 227
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 13
- Variables:
    - Annotated variables: 24
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 13
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `termcolor`

### Stub distribution name

`types-termcolor`

### Number of lines

12 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `termcolor` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `termcolor`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 9
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toml`

### Stub distribution name

`types-toml`

### Number of lines

136 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `toml` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toml`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 71
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 21
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 41
    - Unannotated returns: 0
    - Explicit `Any` returns: 5
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 14
    - Explicit `Any` variables: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 14
    - Class definitions with `Any`: 2
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `toposort`

### Stub distribution name

`types-toposort`

### Number of lines

13 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `toposort` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `toposort`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 4
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 4
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tqdm`

### Stub distribution name

`types-tqdm`

### Number of lines

1,377 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `tqdm` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `tqdm`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 812
    - Unannotated parameters: 142
    - Explicit `Any` parameters: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 42
- Returns:
    - Annotated returns: 167
    - Unannotated returns: 24
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 11
- Variables:
    - Annotated variables: 100
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 74
- Class definitions:
    - Total class definitions: 36
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tree-sitter`

### Stub distribution name

`types-tree-sitter`

### Number of lines

124 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 36 allowlist entries for `tree-sitter` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 25
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 52
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 4
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 7
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tree-sitter-languages`

### Stub distribution name

`types-tree-sitter-languages`

### Number of lines

9 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 3 allowlist entries for `tree-sitter-languages` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tree-sitter-languages`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 2
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 0
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ttkthemes`

### Stub distribution name

`types-ttkthemes`

### Number of lines

76 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ttkthemes` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `ttkthemes`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 30
    - Unannotated parameters: 14
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 3
- Returns:
    - Annotated returns: 13
    - Unannotated returns: 10
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 3
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `typed-ast`

### Stub distribution name

`types-typed-ast`

### Number of lines

578 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `typed-ast` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `typed-ast`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 46
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 29
    - Unannotated returns: 0
    - Explicit `Any` returns: 6
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 309
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 223
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `tzlocal`

### Stub distribution name

`types-tzlocal`

### Number of lines

19 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 2 allowlist entries for `tzlocal` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `tzlocal`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 2
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 3
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `ujson`

### Stub distribution name

`types-ujson`

### Number of lines

34 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `ujson` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `ujson`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 28
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 6
    - Unannotated returns: 0
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `untangle`

### Stub distribution name

`types-untangle`

### Number of lines

33 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `untangle` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `untangle`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 19
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 21
    - Unannotated returns: 0
    - Explicit `Any` returns: 2
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 5
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 2
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `urllib3`

### Stub distribution name

`types-urllib3`

### Number of lines

696 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 30 allowlist entries for `urllib3` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `urllib3`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 158
    - Unannotated parameters: 160
    - Explicit `Any` parameters: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 95
    - Unannotated returns: 61
    - Explicit `Any` returns: 4
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 155
    - Explicit `Any` variables: 54
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 72
    - Class definitions with `Any`: 1
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `vobject`

### Stub distribution name

`types-vobject`

### Number of lines

525 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 11 allowlist entries for `vobject` when running stubtest in CI.

### Pyright settings in CI: *not strict*

This package is tested with pyright in typeshed's CI, but all files in this stubs package are excluded from the stricter pyright settings.

### Statistics on the annotations in typeshed's stubs for `vobject`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 101
    - Unannotated parameters: 179
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 21
- Returns:
    - Annotated returns: 73
    - Unannotated returns: 103
    - Explicit `Any` returns: 3
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 185
    - Explicit `Any` variables: 90
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 3
- Class definitions:
    - Total class definitions: 50
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `waitress`

### Stub distribution name

`types-waitress`

### Number of lines

630 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *missing stubs ignored*

The `--ignore-missing-stub` stubtest setting is used in typeshed's CI.

In CI, stubtest is run on `linux` and `win32`.

Typeshed currently has 38 allowlist entries for `waitress` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `waitress`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 210
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 35
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 9
- Returns:
    - Annotated returns: 209
    - Unannotated returns: 0
    - Explicit `Any` returns: 8
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 246
    - Explicit `Any` variables: 19
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 40
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `whatthepatch`

### Stub distribution name

`types-whatthepatch`

### Number of lines

101 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `whatthepatch` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `whatthepatch`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 32
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 25
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 54
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xmltodict`

### Stub distribution name

`types-xmltodict`

### Number of lines

35 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xmltodict` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xmltodict`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 20
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 7
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 3
    - Unannotated returns: 0
    - Explicit `Any` returns: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 1
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `xxhash`

### Stub distribution name

`types-xxhash`

### Number of lines

43 (excluding blank lines)

### Package status: *obsolete*

The runtime package has added inline type hints; these typeshed stubs are now obsolete.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `xxhash` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `xxhash`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 26
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 17
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 6
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 1
- Class definitions:
    - Total class definitions: 5
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zstd`

### Stub distribution name

`types-zstd`

### Number of lines

13 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 0 allowlist entries for `zstd` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zstd`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 13
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 11
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 0
    - Explicit `Any` variables: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 1
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

---

## Info on typeshed's stubs for `zxcvbn`

### Stub distribution name

`types-zxcvbn`

### Number of lines

162 (excluding blank lines)

### Package status: *up to date*

These stubs should be fairly up to date. In typeshed's CI, [stubtest][] tests these stubs against the latest version of the runtime package that's available.

### Upload status: *uploaded*

These stubs are currently uploaded to PyPI.

### Stubtest settings in CI: *error on missing stub*

Objects missing from the stub cause stubtest to emit an error in typeshed's CI.

In CI, stubtest is run on `linux` only.

Typeshed currently has 1 allowlist entry for `zxcvbn` when running stubtest in CI.

### Pyright settings in CI: *strict*

All files in this stubs package are tested with the stricter pyright settings in typeshed's CI.

### Statistics on the annotations in typeshed's stubs for `zxcvbn`

- Parameters (excluding `self`, `cls`, `metacls` and `mcls`):
    - Annotated parameters: 63
    - Unannotated parameters: 0
    - Explicit `Any` parameters: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) parameters: 0
- Returns:
    - Annotated returns: 39
    - Unannotated returns: 0
    - Explicit `Any` returns: 0
    - Explicitly `Incomplete` (or partially `Incomplete`) returns: 0
- Variables:
    - Annotated variables: 76
    - Explicit `Any` variables: 1
    - Explicitly `Incomplete` (or partially `Incomplete`) variables: 0
- Class definitions:
    - Total class definitions: 9
    - Class definitions with `Any`: 0
    - Class definitions marked as at least partially `Incomplete`: 0

[stubtest]: https://mypy.readthedocs.io/en/stable/stubtest.html "A tool shipped with the mypy type checker for automatically verifying that stubs are consistent with the runtime package"
